goner

package module
v1.3.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 24, 2025 License: MIT Imports: 6 Imported by: 0

README

English  |  中文

license GoDoc Go Report Card codecov Build and Test Release

Goner

Goner is the official component library for the Gone framework, providing a series of plug-and-play components to help developers quickly build high-quality Go applications.

Component List

  • Configuration Management

    • Local Configuration
    • Remote Configuration/Configuration Center [Microservices]
      • goner/apollo - Configuration center component based on Apollo, providing dynamic configuration management
      • goner/nacos - Configuration center component based on Nacos, providing dynamic configuration management
      • goner/viper/remote - Configuration component based on various remote configuration centers (such as etcd, consul, etc.), providing unified configuration management
  • Log Management

  • Service Registry [Microservices]

    • goner/nacos - Service registry component based on Nacos, providing service registration, discovery, and other features
    • goner/etcd - Service registry component based on etcd, providing service registration, discovery, and other features
    • goner/consul - Service registry component based on consul, providing service registration and discovery
  • Message Queue [Microservices] [Event Storming]

  • Services and Remote Calls [Microservices]

    • goner/grpc - gRPC client and server wrapper, simplifying microservice development
    • goner/urllib - HTTP client wrapper
    • goner/gin - Web framework wrapper based on gin-gonic/gin, providing route management, middleware handling, HTTP injection, and other features
    • goner/cmux - Multi-protocol multiplexer based on soheilhy/cmux, supporting multiple protocol services on the same port
  • Database

    • Relational Database
      • goner/xorm - ORM component based on XORM, providing simple and efficient database operations, supporting multiple databases
        • goner/xorm/mysql - MySQL driver wrapper for Xorm, providing database operation functionality
        • goner/xorm/postgres - PostgreSQL driver wrapper for Xorm, providing database operation functionality
        • goner/xorm/sqlite - SQLite driver wrapper for Xorm, providing database operation functionality
        • goner/xorm/mssql - MSSQL driver wrapper for Xorm, providing database operation functionality
      • goner/gorm - ORM component based on GORM, supporting MySQL, PostgreSQL, SQLite, SQL Server, and ClickHouse
        • goner/gorm/mysql - MySQL driver wrapper for Gorm, providing database operation functionality
        • goner/gorm/postgres - PostgreSQL driver wrapper for Gorm, providing database operation functionality
        • goner/gorm/sqlite - SQLite driver wrapper for Gorm, providing database operation functionality
        • goner/gorm/clickhouse - ClickHouse driver wrapper for Gorm, providing database operation functionality
        • goner/gorm/sqlserver - SqlServer driver wrapper for Gorm, providing database operation functionality
    • NoSQL
      • goner/redis - Redis client wrapper, providing caching, distributed locking, and other features
      • goner/mongo - MongoDB client wrapper, providing document database operations with support for multiple database connections
      • goner/es - Elasticsearch client wrapper, providing full-text search functionality
  • Observability [Microservices]

  • Scheduled Tasks

  • AI Components [Large Language Models] [Artificial Intelligence]

    • goner/openai - OpenAI client wrapper, providing GPT and other AI capabilities integration
    • goner/deepseek - Deepseek client wrapper, providing domestic large language model integration
    • goner/mcp - A toolkit wrapped based on github.com/mark3labs/mcp-go that helps developers quickly build MCP (Model Context Protocol) server and client applications. Using the Gone MCP component, you can easily integrate AI models with your business systems.

Installation

# Install Gone CLI tool
go install github.com/gone-io/gonectl@latest

# Install Goner components
# gonectl install <goner component name>
gonectl install goner/gin

Quick Start

Create an application based on Gin, XORM, and Viper using the Gone CLI tool:

  • Create and install dependencies
gonectl create -t gin+xorm+viper goner-demo
cd goner-demo
go mod tidy
  • Run the application
# Start the database
docker compose up -d

# Start the application
go run ./cmd

# Or
# gonectl run ./cmd

Sample code location: gin+xorm+viper

Contributing Guidelines

Contributions of code or issues are welcome! Please follow these steps:

  1. Fork this repository
  2. Create your feature branch (git checkout -b feature/amazing-feature)
  3. Commit your changes (git commit -m 'Add some amazing feature')
  4. Push to the branch (git push origin feature/amazing-feature)
  5. Open a Pull Request

License

This project is licensed under the MIT License - see the LICENSE file for details

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BaseLoad

func BaseLoad(loader gone.Loader) error

func GinLoad

func GinLoad(loader gone.Loader) error

Types

This section is empty.

Directories

Path Synopsis
apollo module
balancer module
cmux module
consul module
deepseek module
es module
etcd module
examples
openai module
g module
gin module
gorm module
clickhouse module
mysql module
postgres module
sqlite module
sqlserver module
grpc module
interfaces module
mcp module
mongo module
mq
kafka module
mqtt module
rabbitmq module
rocket module
nacos module
openai module
otel module
log module
log/grpc module
log/http module
meter module
meter/grpc module
meter/http module
tracer module
tracer/grpc module
tracer/http module
redis module
schedule module
tracer module
gid module
gls module
urllib module
viper module
remote module
xorm module
mysql module
postgres module
sqlite module
zap module

Jump to