Documentation
¶
Overview ¶
Package etcd is a generated GoMock package.
Index ¶
- func ClientLoad(loader gone.Loader) error
- func ProvideEtecd3Client(_ string, param struct{ ... }) (*etcd3.Client, error)
- func RegistryLoad(loader gone.Loader) error
- type MockKV
- func (m *MockKV) Compact(ctx context.Context, rev int64, opts ...clientv3.CompactOption) (*clientv3.CompactResponse, error)
- func (m *MockKV) Delete(ctx context.Context, key string, opts ...clientv3.OpOption) (*clientv3.DeleteResponse, error)
- func (m *MockKV) Do(ctx context.Context, op clientv3.Op) (clientv3.OpResponse, error)
- func (m *MockKV) EXPECT() *MockKVMockRecorder
- func (m *MockKV) Get(ctx context.Context, key string, opts ...clientv3.OpOption) (*clientv3.GetResponse, error)
- func (m *MockKV) Put(ctx context.Context, key, val string, opts ...clientv3.OpOption) (*clientv3.PutResponse, error)
- func (m *MockKV) Txn(ctx context.Context) clientv3.Txn
- type MockKVMockRecorder
- func (mr *MockKVMockRecorder) Compact(ctx, rev any, opts ...any) *gomock.Call
- func (mr *MockKVMockRecorder) Delete(ctx, key any, opts ...any) *gomock.Call
- func (mr *MockKVMockRecorder) Do(ctx, op any) *gomock.Call
- func (mr *MockKVMockRecorder) Get(ctx, key any, opts ...any) *gomock.Call
- func (mr *MockKVMockRecorder) Put(ctx, key, val any, opts ...any) *gomock.Call
- func (mr *MockKVMockRecorder) Txn(ctx any) *gomock.Call
- type MockLease
- func (m *MockLease) Close() error
- func (m *MockLease) EXPECT() *MockLeaseMockRecorder
- func (m *MockLease) Grant(ctx context.Context, ttl int64) (*clientv3.LeaseGrantResponse, error)
- func (m *MockLease) KeepAlive(ctx context.Context, id clientv3.LeaseID) (<-chan *clientv3.LeaseKeepAliveResponse, error)
- func (m *MockLease) KeepAliveOnce(ctx context.Context, id clientv3.LeaseID) (*clientv3.LeaseKeepAliveResponse, error)
- func (m *MockLease) Leases(ctx context.Context) (*clientv3.LeaseLeasesResponse, error)
- func (m *MockLease) Revoke(ctx context.Context, id clientv3.LeaseID) (*clientv3.LeaseRevokeResponse, error)
- func (m *MockLease) TimeToLive(ctx context.Context, id clientv3.LeaseID, opts ...clientv3.LeaseOption) (*clientv3.LeaseTimeToLiveResponse, error)
- type MockLeaseMockRecorder
- func (mr *MockLeaseMockRecorder) Close() *gomock.Call
- func (mr *MockLeaseMockRecorder) Grant(ctx, ttl any) *gomock.Call
- func (mr *MockLeaseMockRecorder) KeepAlive(ctx, id any) *gomock.Call
- func (mr *MockLeaseMockRecorder) KeepAliveOnce(ctx, id any) *gomock.Call
- func (mr *MockLeaseMockRecorder) Leases(ctx any) *gomock.Call
- func (mr *MockLeaseMockRecorder) Revoke(ctx, id any) *gomock.Call
- func (mr *MockLeaseMockRecorder) TimeToLive(ctx, id any, opts ...any) *gomock.Call
- type MockWatcher
- type MockWatcherMockRecorder
- type Registry
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClientLoad ¶
func ProvideEtecd3Client ¶
func RegistryLoad ¶
Types ¶
type MockKV ¶
type MockKV struct {
// contains filtered or unexported fields
}
MockKV is a mock of KV interface.
func NewMockKV ¶
func NewMockKV(ctrl *gomock.Controller) *MockKV
NewMockKV creates a new mock instance.
func (*MockKV) Compact ¶
func (m *MockKV) Compact(ctx context.Context, rev int64, opts ...clientv3.CompactOption) (*clientv3.CompactResponse, error)
Compact mocks base method.
func (*MockKV) Delete ¶
func (m *MockKV) Delete(ctx context.Context, key string, opts ...clientv3.OpOption) (*clientv3.DeleteResponse, error)
Delete mocks base method.
func (*MockKV) EXPECT ¶
func (m *MockKV) EXPECT() *MockKVMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockKV) Get ¶
func (m *MockKV) Get(ctx context.Context, key string, opts ...clientv3.OpOption) (*clientv3.GetResponse, error)
Get mocks base method.
type MockKVMockRecorder ¶
type MockKVMockRecorder struct {
// contains filtered or unexported fields
}
MockKVMockRecorder is the mock recorder for MockKV.
func (*MockKVMockRecorder) Compact ¶
func (mr *MockKVMockRecorder) Compact(ctx, rev any, opts ...any) *gomock.Call
Compact indicates an expected call of Compact.
func (*MockKVMockRecorder) Delete ¶
func (mr *MockKVMockRecorder) Delete(ctx, key any, opts ...any) *gomock.Call
Delete indicates an expected call of Delete.
func (*MockKVMockRecorder) Do ¶
func (mr *MockKVMockRecorder) Do(ctx, op any) *gomock.Call
Do indicates an expected call of Do.
func (*MockKVMockRecorder) Get ¶
func (mr *MockKVMockRecorder) Get(ctx, key any, opts ...any) *gomock.Call
Get indicates an expected call of Get.
type MockLease ¶
type MockLease struct {
// contains filtered or unexported fields
}
MockLease is a mock of Lease interface.
func NewMockLease ¶
func NewMockLease(ctrl *gomock.Controller) *MockLease
NewMockLease creates a new mock instance.
func (*MockLease) EXPECT ¶
func (m *MockLease) EXPECT() *MockLeaseMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockLease) KeepAlive ¶
func (m *MockLease) KeepAlive(ctx context.Context, id clientv3.LeaseID) (<-chan *clientv3.LeaseKeepAliveResponse, error)
KeepAlive mocks base method.
func (*MockLease) KeepAliveOnce ¶
func (m *MockLease) KeepAliveOnce(ctx context.Context, id clientv3.LeaseID) (*clientv3.LeaseKeepAliveResponse, error)
KeepAliveOnce mocks base method.
func (*MockLease) Revoke ¶
func (m *MockLease) Revoke(ctx context.Context, id clientv3.LeaseID) (*clientv3.LeaseRevokeResponse, error)
Revoke mocks base method.
func (*MockLease) TimeToLive ¶
func (m *MockLease) TimeToLive(ctx context.Context, id clientv3.LeaseID, opts ...clientv3.LeaseOption) (*clientv3.LeaseTimeToLiveResponse, error)
TimeToLive mocks base method.
type MockLeaseMockRecorder ¶
type MockLeaseMockRecorder struct {
// contains filtered or unexported fields
}
MockLeaseMockRecorder is the mock recorder for MockLease.
func (*MockLeaseMockRecorder) Close ¶
func (mr *MockLeaseMockRecorder) Close() *gomock.Call
Close indicates an expected call of Close.
func (*MockLeaseMockRecorder) Grant ¶
func (mr *MockLeaseMockRecorder) Grant(ctx, ttl any) *gomock.Call
Grant indicates an expected call of Grant.
func (*MockLeaseMockRecorder) KeepAlive ¶
func (mr *MockLeaseMockRecorder) KeepAlive(ctx, id any) *gomock.Call
KeepAlive indicates an expected call of KeepAlive.
func (*MockLeaseMockRecorder) KeepAliveOnce ¶
func (mr *MockLeaseMockRecorder) KeepAliveOnce(ctx, id any) *gomock.Call
KeepAliveOnce indicates an expected call of KeepAliveOnce.
func (*MockLeaseMockRecorder) Leases ¶
func (mr *MockLeaseMockRecorder) Leases(ctx any) *gomock.Call
Leases indicates an expected call of Leases.
func (*MockLeaseMockRecorder) Revoke ¶
func (mr *MockLeaseMockRecorder) Revoke(ctx, id any) *gomock.Call
Revoke indicates an expected call of Revoke.
func (*MockLeaseMockRecorder) TimeToLive ¶
func (mr *MockLeaseMockRecorder) TimeToLive(ctx, id any, opts ...any) *gomock.Call
TimeToLive indicates an expected call of TimeToLive.
type MockWatcher ¶
type MockWatcher struct {
// contains filtered or unexported fields
}
MockWatcher is a mock of Watcher interface.
func NewMockWatcher ¶
func NewMockWatcher(ctrl *gomock.Controller) *MockWatcher
NewMockWatcher creates a new mock instance.
func (*MockWatcher) EXPECT ¶
func (m *MockWatcher) EXPECT() *MockWatcherMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockWatcher) RequestProgress ¶
func (m *MockWatcher) RequestProgress(ctx context.Context) error
RequestProgress mocks base method.
type MockWatcherMockRecorder ¶
type MockWatcherMockRecorder struct {
// contains filtered or unexported fields
}
MockWatcherMockRecorder is the mock recorder for MockWatcher.
func (*MockWatcherMockRecorder) Close ¶
func (mr *MockWatcherMockRecorder) Close() *gomock.Call
Close indicates an expected call of Close.
func (*MockWatcherMockRecorder) RequestProgress ¶
func (mr *MockWatcherMockRecorder) RequestProgress(ctx any) *gomock.Call
RequestProgress indicates an expected call of RequestProgress.